@@ -26,15 +26,6 @@ if [ ! -d "$basepath/systemd_el" ]; then
         cp -r "$basepath/base" "$basepath/systemd_el"
         DESTDIR="$basepath/systemd_el" bash install.sh systemd_redhat
 fi
-if [ ! -d "$basepath/old_el" ]; then
-        cp -r "$basepath/base" "$basepath/old_el"
-        DESTDIR="$basepath/old_el" bash install.sh sysv_init_redhat
-fi
-if [ ! -d "$basepath/old_sles" ]; then
-        cp -r "$basepath/base" "$basepath/old_sles"
-        DESTDIR="$basepath/old_sles" bash install.sh sysv_init_suse
-fi
-
 
 # things are only different if we have docs, deb docs get
 # installed in an unversioned folder but rpm docs get installed
@@ -46,28 +37,12 @@ if [ -d ext/docs ]; then
                         cp -r "$basepath/base_deb" "$basepath/systemd_deb"
                         DESTDIR="$basepath/systemd_deb" bash install.sh systemd_deb
                 fi
-                if [ ! -d "$basepath/systemd_notasksmax_deb" ]; then
-                        cp -r "$basepath/base_deb" "$basepath/systemd_notasksmax_deb"
-                        DESTDIR="$basepath/systemd_notasksmax_deb" USE_TASKSMAX=false bash install.sh systemd_deb
-                fi
-                if [ ! -d "$basepath/sysvinit_deb" ]; then
-                        cp -r "$basepath/base_deb" "$basepath/sysvinit_deb"
-                        DESTDIR="$basepath/sysvinit_deb" bash install.sh sysv_init_deb
-                fi
         fi
 else
         if [ ! -d "$basepath/systemd_deb" ]; then
                 cp -r "$basepath/base" "$basepath/systemd_deb"
                 DESTDIR="$basepath/systemd_deb" bash install.sh systemd_deb
         fi
-        if [ ! -d "$basepath/systemd_notasksmax_deb" ]; then
-                cp -r "$basepath/base" "$basepath/systemd_notasksmax_deb"
-                DESTDIR="$basepath/systemd_notasksmax_deb" USE_TASKSMAX=false bash install.sh systemd_deb
-        fi
-        if [ ! -d "$basepath/sysvinit_deb" ]; then
-                cp -r "$basepath/base" "$basepath/sysvinit_deb"
-                DESTDIR="$basepath/sysvinit_deb" bash install.sh sysv_init_deb
-        fi
 fi
 
 os=$build_os
@@ -81,33 +56,11 @@ case $os in
         # there's no differences in packaging for deb vs ubuntu
         # if that changes we'll need to fix this
         debian|ubuntu)
-                if [ "$os_dist" = 'trusty' ]; then
-                        dir="$basepath/sysvinit_deb"
-                elif [ "$os_dist" = 'jessie' ]; then
-                        # the version of systemd that ships with jessie doesn't
-                        # support TasksMax
-                        dir="$basepath/systemd_notasksmax_deb"
-                else
-                        dir="$basepath/systemd_deb"
-                fi
+                dir="$basepath/systemd_deb"
                 ;;
-        el|redhatfips)
-                if [ "$os_version" -gt '6' ]; then
-                        dir="$basepath/systemd_el"
-                else
-                        dir="$basepath/old_el"
-                fi
-                ;;
-        amazon)
+        amazon|el|fedora|redhatfips|sles)
                 dir="$basepath/systemd_el"
                 ;;
-        sles)
-                if [ "$os_version" -gt '11' ]; then
-                        dir="$basepath/systemd_el"
-                else
-                        dir="$basepath/old_sles"
-                fi
-                ;;
         *)
                 echo "I have no idea what I'm doing with $os, teach me?" >&2
                 exit 1
@@ -115,11 +68,11 @@ case $os in
 esac
 
 # bash will eat your spaces, so let's array. see http://mywiki.wooledge.org/BashFAQ/050 for more fun.
-params=("--user" "puppet" "--group" "puppet" "--chdir" "$dir" "--realname" "puppetserver" "--operating-system" "$os" "--name" "openvox-server" "--package-version" "8.11.0" "--release" "1" "--platform-version" "8")
+params=("--user" "puppet" "--group" "puppet" "--chdir" "$dir" "--realname" "puppetserver" "--operating-system" "$os" "--name" "openvox-server" "--package-version" "8.12.0" "--release" "1" "--platform-version" "8")
 if [ -n "$os_version" ]; then params+=("--os-version" "$os_version"); fi
 if [ -n "$os_dist" ]; then params+=("--dist" "$os_dist"); fi
 
-params+=('--description' "$(printf "Vox Pupuli puppetserver\nContains: OpenVox Server (puppetlabs/puppetserver 8.11.0,org.clojure/clojure 1.11.2,org.bouncycastle/bcpkix-jdk18on 1.78.1,puppetlabs/jruby-utils 5.2.0,puppetlabs/puppetserver 8.11.0,com.puppetlabs/trapperkeeper-webserver-jetty10 1.0.18,puppetlabs/trapperkeeper-metrics 2.0.4)")")
+params+=('--description' "$(printf "Vox Pupuli puppetserver\nContains: OpenVox Server (org.openvoxproject/puppetserver 8.12.0,org.clojure/clojure 1.12.4,org.bouncycastle/bcpkix-jdk18on 1.83,org.openvoxproject/jruby-utils 5.3.5,org.openvoxproject/puppetserver 8.12.0,org.openvoxproject/trapperkeeper-webserver-jetty10 1.1.3,org.openvoxproject/trapperkeeper-metrics 2.1.6)")")
 
 
 
@@ -130,7 +83,6 @@ params+=('--create-dir' '/opt/puppetlabs/server/data/puppetserver/jars')
 params+=('--create-dir' '/opt/puppetlabs/server/data/puppetserver/yaml')
 
 
-
 if [[ "$os" = 'el' || "$os" = 'sles' || "$os" = 'fedora' || "$os" = 'redhatfips' || "$os" = 'amazon' ]]; then
         # pull in rpm dependencies
                         params+=("--additional-dependency")
