@@ -6,17 +6,12 @@ require 'ostruct'
 
 options = OpenStruct.new
 # settin' some defaults
-options.systemd = 0
-options.sysvinit = 0
 options.systemd_el = 0
 options.systemd_sles = 0
-options.old_el = 0
-options.old_sles = 0
 options.sles = 0
 options.java = 'java-1.8.0-openjdk-headless'
 options.release = 1
 options.platform_version = 0
-options.is_pe = false
 options.replaces = {}
 options.additional_dependencies = []
 options.user = 'puppet'
@@ -53,9 +48,6 @@ OptionParser.new do |opts|
   opts.on('--platform-version VERSION', Integer, 'VERSION of the puppet platform this builds for') do |v|
     options.platform_version = v
   end
-  opts.on('--[no-]enterprise-build', 'Whether or not this is a PE build') do |e|
-    options.is_pe = e
-  end
   opts.on('--replaces <PKG,VERSION>', Array, 'PKG and VERSION replaced by this package. Can be passed multiple times.') do |pkg,ver|
     options.replaces[pkg] = ver
   end
@@ -140,17 +132,9 @@ fail "--dist is required!" if options.output_type == 'deb' && options.dist.nil?
 if options.sources.empty?
   options.sources = case options.operating_system
                     when :amazon, :fedora, :sles, :el, :redhatfips
-                      if options.operating_system == :el && options.os_version < 7 || options.operating_system == :sles && options.os_version < 12 #sysv rpm platforms
-                        ['etc', 'opt', 'var']
-                      else
-                        ['etc', 'opt', 'usr', 'var']
-                      end
+                      ['etc', 'opt', 'usr', 'var']
                     when :debian, :ubuntu
-                      if options.dist == 'trusty' #trusty is the only sysv deb we build for right now
-                        ['etc', 'opt', 'var']
-                      else
-                        ['etc', 'lib', 'opt', 'usr', 'var']
-                      end
+                      ['etc', 'lib', 'opt', 'usr', 'var']
                     else
                       fail "I don't know what your default sources should be, pass it on the command line!"
                     end
@@ -176,51 +160,37 @@ if options.output_type == 'rpm'
   fpm_opts << "--rpm-rpmbuild-define '_app_prefix #{options.app_prefix}'"
   fpm_opts << "--rpm-rpmbuild-define '_app_data #{options.app_data}'"
 
-  if options.operating_system == :fedora # all supported fedoras are systemd
+  if options.operating_system == :fedora # all supported fedoras are systemd and provide Java 21
     options.systemd = 1
     options.systemd_el = 1
+    options.java = 'jre-21-headless'
+    options.java_bin = '/usr/lib/jvm/jre-21/bin/java'
   elsif options.operating_system == :amazon
     fpm_opts << "--depends tzdata-java"
-    options.java = '(java-17-amazon-corretto-headless or java-11-amazon-corretto-headless)'
+    options.java = 'java-17-amazon-corretto-headless'
     options.systemd = 1
     options.systemd_el = 1
-  elsif options.operating_system == :el
-    if options.os_version == 7
-      options.java = 'jre-11-headless'
-      options.java_bin = '/usr/lib/jvm/jre-11/bin/java'
+  elsif options.operating_system == :el || options.operating_system == :redhatfips
+    if options.os_version <= 7
+      raise "el version #{options.os_version} is no longer supported"
     elsif (8..9).include?(options.os_version)
       options.java = 'jre-17-headless'
       options.java_bin = '/usr/lib/jvm/jre-17/bin/java'
-    elsif options.os_version == 10
+    elsif options.os_version >= 10
       options.java = 'jre-21-headless'
       options.java_bin = '/usr/lib/jvm/jre-21/bin/java'
     else
       fail "Unrecognized el os version #{options.os_version}"
     end
-
-    options.systemd = 1
     options.systemd_el = 1
-  elsif options.operating_system == :redhatfips && options.os_version >= 7 # systemd redhatfips
-    options.systemd = 1
-    options.systemd_el = 1
-  elsif options.operating_system == :sles && options.os_version >= 12 # systemd sles
-    options.systemd = 1
+  elsif options.operating_system == :sles
     options.systemd_sles = 1
     options.sles = 1
-    if ! options.is_pe
-      options.java = 'java-11-openjdk-headless'
-    end
-  elsif options.operating_system == :sles #old sles
-    options.sysvinit = 1
-    options.old_sles = 1
+    options.java = 'java-17-openjdk-headless'
   end
 
-  fpm_opts << "--rpm-rpmbuild-define '_with_sysvinit #{options.sysvinit}'"
-  fpm_opts << "--rpm-rpmbuild-define '_with_systemd #{options.systemd}'"
-  fpm_opts << "--rpm-rpmbuild-define '_old_sles #{options.old_sles}'"
   fpm_opts << "--rpm-rpmbuild-define '_systemd_el #{options.systemd_el}'"
   fpm_opts << "--rpm-rpmbuild-define '_systemd_sles #{options.systemd_sles}'"
-  fpm_opts << "--rpm-rpmbuild-define '_old_el #{options.old_el}'"
   fpm_opts << "--rpm-rpmbuild-define '_sysconfdir /etc'"
   fpm_opts << "--rpm-rpmbuild-define '_prefix #{options.app_prefix}'"
   fpm_opts << "--rpm-rpmbuild-define '_rundir /var/run'"
@@ -228,12 +198,6 @@ if options.output_type == 'rpm'
 
   shared_opts << "--rpm-dist #{options.dist}"
 
-  if options.old_el == 1
-    fpm_opts << "--depends chkconfig"
-  elsif options.old_sles == 1
-    fpm_opts << "--depends aaa_base"
-  end
-
   if options.systemd_el == 1
     fpm_opts << "--depends systemd"
   end
@@ -271,10 +235,7 @@ if options.output_type == 'rpm'
   fpm_opts << "--rpm-auto-add-exclude-directories /opt/puppetlabs/server/data"
   fpm_opts << "--rpm-auto-add-exclude-directories /usr/lib/systemd"
   fpm_opts << "--rpm-auto-add-exclude-directories /usr/lib/systemd/system"
-  fpm_opts << "--rpm-auto-add-exclude-directories /etc/init.d"
-  fpm_opts << "--rpm-auto-add-exclude-directories /etc/rc.d"
   fpm_opts << "--rpm-auto-add-exclude-directories /etc/logrotate.d"
-  fpm_opts << "--rpm-auto-add-exclude-directories /etc/rc.d/init.d"
   fpm_opts << "--rpm-auto-add-exclude-directories /usr/lib/tmpfiles.d"
   fpm_opts << "--rpm-auto-add-exclude-directories /var/log/puppetlabs"
   fpm_opts << "--rpm-auto-add-exclude-directories /var/run/puppetlabs"
@@ -308,19 +269,13 @@ elsif options.output_type == 'deb'
     options.release = "#{options.release}+#{options.dist}"
   end
 
-  if ! options.is_pe
-    options.java = 'openjdk-17-jre-headless | openjdk-11-jre-headless'
-  end
+  options.java = 'openjdk-21-jre-headless | openjdk-17-jre-headless'
 
   fpm_opts << '--deb-build-depends cdbs'
   fpm_opts << '--deb-build-depends bc'
   fpm_opts << '--deb-build-depends mawk'
   fpm_opts << '--deb-build-depends lsb-release'
-  if options.is_pe
-    fpm_opts << '--deb-build-depends puppet-agent'
-  else
-    fpm_opts << '--deb-build-depends "ruby | ruby-interpreter"'
-  end
+  fpm_opts << '--deb-build-depends "ruby | ruby-interpreter"'
   fpm_opts << '--deb-priority optional'
   fpm_opts << '--category utils'
   options.deb_interest_triggers.each do |trigger|
@@ -383,13 +338,7 @@ if options.name == "openvoxdb"
   termini_opts << "--conflicts 'puppetdb-termini'"
 end
 
-if options.is_pe
-  fpm_opts << "--depends pe-java"
-  fpm_opts << "--depends pe-puppet-enterprise-release"
-  fpm_opts << "--depends pe-bouncy-castle-jars"
-else
-  fpm_opts << "--depends '#{options.java}'"
-end
+fpm_opts << "--depends '#{options.java}'"
 
 fpm_opts << "--depends bash"
 fpm_opts << "--depends net-tools"
