@@ -34,7 +34,6 @@ dest_apps_dir="${DESTDIR}${app_prefix}"
 app_data=${app_data:=/opt/puppetlabs/server/data/${real_name}}
 app_logdir=${app_logdir:=/var/log/puppetlabs/${real_name}}
 system_config_dir=${system_config_dir:=${app_prefix}/config}
-needrestart_confdir=${needrestart_dir:=/etc/needrestart/conf.d}
 
 
 ##################
@@ -74,36 +73,17 @@ function task_service {
     if [ "$OSFAMILY" = "RedHat" ]; then
         unitdir=${unitdir_redhat}
         defaultsdir=${defaultsdir_redhat}
-        if [ $MAJREV -lt 7 ]; then
-            task install_source_rpm_sysv
-        else
-            task install_source_rpm_systemd
-        fi
+        task install_source_rpm_systemd
     elif [ "$OSFAMILY" = "Debian" ]; then
         unitdir=${unitdir_debian}
         defaultsdir=${defaultsdir_debian}
-        sysv_codenames=("squeeze" "wheezy" "lucid" "precise" "trusty")
-        if $(echo ${sysv_codenames[@]} | grep -q $CODENAME) ; then
-            task install_source_deb_sysv
-        else
-            task install_source_deb_systemd
-        fi
+        task install_source_deb_systemd
     else
         echo "Unsupported platform, exiting ..."
         exit 1
     fi
 }
 
-# Source based install for Redhat based + sysv setups
-function task_install_source_rpm_sysv {
-    task preinst_redhat
-    task install_redhat
-    task sysv_init_redhat
-    task logrotate_legacy
-    task postinst_redhat
-    task postinst_permissions
-}
-
 # Source based install for Redhat based + systemd setups
 function task_install_source_rpm_systemd {
     task preinst_redhat
@@ -114,15 +94,6 @@ function task_install_source_rpm_systemd {
     task postinst_permissions
 }
 
-# Source based install for Debian based + sysv setups
-function task_install_source_deb_sysv {
-    task preinst_deb
-    task install_deb
-    task sysv_init_deb
-    task logrotate
-    task postinst_deb
-}
-
 # Source based install for Debian based + systemd setups
 function task_install_source_deb_systemd {
     task preinst_deb
@@ -143,8 +114,8 @@ function task_install_docs_deb {
 # install docs for rpm based systems
 function task_install_docs_rpm {
   if [ -d ext/docs ]; then
-    install -d "${DESTDIR}${app_prefix}/share/doc/puppetserver-8.11.0"
-    cp -a ext/docs "${DESTDIR}${app_prefix}/share/doc/puppetserver-8.11.0"
+    install -d "${DESTDIR}${app_prefix}/share/doc/puppetserver-8.12.0"
+    cp -a ext/docs "${DESTDIR}${app_prefix}/share/doc/puppetserver-8.12.0"
   fi
 }
 
@@ -164,16 +135,16 @@ function task_install {
 
         install -m 0644 ext/system-config/services.d/bootstrap.cfg "${DESTDIR}${system_config_dir}/services.d/bootstrap.cfg"
     
-    install -m 0644 ext/config/conf.d/puppetserver.conf "${DESTDIR}${projconfdir}/conf.d/puppetserver.conf"
     install -m 0644 ext/config/request-logging.xml "${DESTDIR}${projconfdir}/request-logging.xml"
+    install -m 0644 ext/config/conf.d/puppetserver.conf "${DESTDIR}${projconfdir}/conf.d/puppetserver.conf"
     install -m 0644 ext/config/logback.xml "${DESTDIR}${projconfdir}/logback.xml"
+    install -m 0644 ext/config/services.d/ca.cfg "${DESTDIR}${projconfdir}/services.d/ca.cfg"
     install -m 0644 ext/config/conf.d/global.conf "${DESTDIR}${projconfdir}/conf.d/global.conf"
     install -m 0644 ext/config/conf.d/web-routes.conf "${DESTDIR}${projconfdir}/conf.d/web-routes.conf"
     install -m 0644 ext/config/conf.d/auth.conf "${DESTDIR}${projconfdir}/conf.d/auth.conf"
     install -m 0644 ext/config/conf.d/metrics.conf "${DESTDIR}${projconfdir}/conf.d/metrics.conf"
     install -m 0644 ext/config/conf.d/ca.conf "${DESTDIR}${projconfdir}/conf.d/ca.conf"
     install -m 0644 ext/config/conf.d/webserver.conf "${DESTDIR}${projconfdir}/conf.d/webserver.conf"
-    install -m 0644 ext/config/services.d/ca.cfg "${DESTDIR}${projconfdir}/services.d/ca.cfg"
 
     install -d -m 0755 "${dest_apps_dir}/scripts"
     install -m 0755 install.sh "${dest_apps_dir}/scripts"
@@ -186,15 +157,15 @@ function task_install {
     ln -s "../apps/${real_name}/bin/${real_name}" "${DESTDIR}${symbindir}/${real_name}"
     install -d -m 0755 "${DESTDIR}${uxbindir}"
     ln -s "../server/apps/${real_name}/bin/${real_name}" "${DESTDIR}${uxbindir}/${real_name}"
+    install -m 0755 ext/cli/stop "${dest_apps_dir}/cli/apps/stop"
     install -m 0755 ext/cli/foreground "${dest_apps_dir}/cli/apps/foreground"
-    install -m 0755 ext/cli/irb "${dest_apps_dir}/cli/apps/irb"
+    install -m 0755 ext/cli/start "${dest_apps_dir}/cli/apps/start"
     install -m 0755 ext/cli/ca "${dest_apps_dir}/cli/apps/ca"
     install -m 0755 ext/cli/gem "${dest_apps_dir}/cli/apps/gem"
-    install -m 0755 ext/cli/stop "${dest_apps_dir}/cli/apps/stop"
-    install -m 0755 ext/cli/start "${dest_apps_dir}/cli/apps/start"
-    install -m 0755 ext/cli/ruby "${dest_apps_dir}/cli/apps/ruby"
-    install -m 0755 ext/cli/reload "${dest_apps_dir}/cli/apps/reload"
     install -m 0755 ext/cli/prune "${dest_apps_dir}/cli/apps/prune"
+    install -m 0755 ext/cli/reload "${dest_apps_dir}/cli/apps/reload"
+    install -m 0755 ext/cli/irb "${dest_apps_dir}/cli/apps/irb"
+    install -m 0755 ext/cli/ruby "${dest_apps_dir}/cli/apps/ruby"
 
 if [ -e "ext/cli_defaults/cli-defaults.sh" ]; then
     install -m 0755 ext/cli_defaults/cli-defaults.sh "${dest_apps_dir}/cli/"
@@ -210,12 +181,16 @@ function task_install_redhat {
     task install
     task install_docs_rpm
     bash ./ext/build-scripts/install-vendored-gems.sh
+    install -d -m 0700 "${DESTDIR}${app_data}/jars"
+    if [ -d ext/build-scripts/bc-fips-jars ]; then files=(ext/build-scripts/bc-fips-jars/*); install -m 0644 "${files[@]}" "${DESTDIR}${app_data}/jars/"; install -m 0644 ext/build-scripts/java.security.fips "${DESTDIR}${app_data}/"; fi
 }
 
 function task_install_deb {
     task install
     task install_docs_deb
     bash ./ext/build-scripts/install-vendored-gems.sh
+    install -d -m 0700 "${DESTDIR}${app_data}/jars"
+    if [ -d ext/build-scripts/bc-fips-jars ]; then files=(ext/build-scripts/bc-fips-jars/*); install -m 0644 "${files[@]}" "${DESTDIR}${app_data}/jars/"; install -m 0644 ext/build-scripts/java.security.fips "${DESTDIR}${app_data}/"; fi
 }
 
 
@@ -229,20 +204,6 @@ function task_defaults_deb {
     install -m 0644 ext/debian/puppetserver.default_file "${DESTDIR}${defaultsdir_debian}/puppetserver"
 }
 
-# Install the sysv and defaults configuration for Redhat.
-function task_sysv_init_redhat {
-    task defaults_redhat
-    install -d -m 0755 "${DESTDIR}${initdir}"
-    install -m 0755 ext/redhat/init "${DESTDIR}${initdir}/puppetserver"
-}
-
-# Install the sysv and defaults configuration for SuSE.
-function task_sysv_init_suse {
-    task defaults_redhat
-    install -d -m 0755 "${DESTDIR}${initdir}"
-    install -m 0755 ext/redhat/init.suse "${DESTDIR}${initdir}/puppetserver"
-}
-
 # Install the systemd and defaults configuration for Redhat.
 function task_systemd_redhat {
     task defaults_redhat
@@ -252,26 +213,13 @@ function task_systemd_redhat {
     install -m 0644 ext/puppetserver.tmpfiles.conf "${DESTDIR}${tmpfilesdir}/puppetserver.conf"
 }
 
-# Install the sysv and defaults configuration for Debian.
-function task_sysv_init_deb {
-    task defaults_deb
-    install -d -m 0755 "${DESTDIR}${initdir}"
-    install -m 0755 ext/debian/puppetserver.init_script "${DESTDIR}${initdir}/puppetserver"
-    install -d -m 0755 "${DESTDIR}${rundir}"
-}
-
-# Install the systemd/sysv and defaults configuration for Debian.
+# Install the systemd and defaults configuration for Debian.
 function task_systemd_deb {
-    task sysv_init_deb
+    task defaults_deb
     install -d -m 0755 "${DESTDIR}${unitdir_debian}"
     install -m 0644 ext/debian/puppetserver.service_file "${DESTDIR}${unitdir_debian}/puppetserver.service"
-    if [ "$USE_TASKSMAX" == "false" ]; then
-      sed -i "s/^TasksMax/# Don't set TasksMax since the option doesn't exist\n# TasksMax/" "${DESTDIR}${unitdir_debian}/puppetserver.service"
-    fi
     install -d -m 0755 "${DESTDIR}${tmpfilesdir}"
     install -m 0644 ext/puppetserver.tmpfiles.conf "${DESTDIR}${tmpfilesdir}/puppetserver.conf"
-    install -d -m 0755 "${DESTDIR}${needrestart_confdir}"
-    install -m 0644 ext/puppetserver.needrestart.conf "${DESTDIR}${needrestart_confdir}/puppetserver.conf"
 }
 
 function task_service_account {
@@ -344,6 +292,7 @@ function task_postinst_redhat_install {
     install --directory /etc/puppetlabs/puppet/ssl
     chown -R puppet:puppet /etc/puppetlabs/puppet/ssl
     find /etc/puppetlabs/puppet/ssl -type d -print0 | xargs -0 chmod 770
+    chown puppet:puppet /opt/puppetlabs/server/data/puppetserver/java.security.fips
 }
 
 # Global post installation permissions setup. Not to be used by Redhat
@@ -364,18 +313,12 @@ function task_postinst_permissions {
     chmod 700 /opt/puppetlabs/server/data/puppetserver/yaml
 }
 
-# Install logrotate (usually el7, fedora 16 and above)
+# Install logrotate
 function task_logrotate {
     install -d -m 0755 "${DESTDIR}${confdir}/logrotate.d"
     cp -pr ext/puppetserver.logrotate.conf "${DESTDIR}${confdir}/logrotate.d/puppetserver"
 }
 
-# Install legacy logrotate
-function task_logrotate_legacy {
-    install -d -m 0755 "${DESTDIR}${confdir}/logrotate.d"
-    cp -pr ext/puppetserver.logrotate-legacy.conf "${DESTDIR}${confdir}/logrotate.d/puppetserver"
-}
-
 ##################
 # Misc functions #
 ##################
